Path

Struct Path 

pub struct Path<'a> { /* private fields */ }
Path provides a copy-on-write-style path that is built around UTF8 strings.

Implementations

Source

impl<'a> Path<'a>

pub const fn new(s: &'a str) -> Self

Create a new path that borrows the provided string.

pub fn into_owned(self) -> Path<'static>

Convert the path into an owned path.

pub fn into_std(&self) -> &Path

View the path as a std::path::Path.

pub fn as_std_path(&self) -> &Path

Convert the path to a std::path::Path.

pub fn as_os_str(&self) -> &OsStr

Convert the path to an OsStr.

pub fn as_str(&self) -> &str

Convert the path to a str.

pub fn to_str(&self) -> Option<&str>

Convert the path to a str.

pub fn to_string_lossy(&self) -> Cow<'_, str>

Convert the path to a string, losslessly because this type is always UTF-8.

pub fn to_path_buf(&self) -> PathBuf

Convert the path to a std::path::PathBuf.

pub fn is_dir(&self) -> Result<bool>

Is the path a directory?

pub fn is_file(&self) -> Result<bool>

Is the path a file?

Is the path a symbolic link?

pub fn basename(&self) -> Path<'_>

Compute the basename of the path. This is guaranteed to be a non-empty path component (falling back to “.” for paths that end with “/”).

pub fn dirname(&self) -> Path<'_>

Compute the dirname of the path. This is guaranteed to be a non-empty path component (falling back to “.” or “/” for single-component paths).

pub fn exists(&self) -> Result<bool>

True if the path exists.

pub fn try_exists(&self) -> Result<bool>

Return whether the path exists, preserving I/O errors.

pub fn metadata(&self) -> Result<Metadata>

Query the filesystem for metadata, following symbolic links.

Query the filesystem for metadata without following symbolic links.

Read the target of a symbolic link.

pub fn read_dir(&self) -> Result<ReadDir>

Return an iterator over the entries in this directory.

pub fn has_root(&self) -> bool

True if the path begins with some number of slashes, other than the POSIX-exception of //.

pub fn has_app_defined(&self) -> bool

True if the path begins with //, but not ///.

pub fn is_abs(&self) -> bool

True if the path is absolute.

pub fn is_absolute(&self) -> bool

True if the path is absolute.

pub fn is_relative(&self) -> bool

True if the path is relative.

pub fn is_normal(&self) -> bool

True if the path contains no “.” components; and, is absolute and has no “..” components, or is relative and has all “..” components at the start.

pub fn join<'b, 'c>(&self, with: impl Into<Path<'b>>) -> Path<'c>
where 'a: 'c, 'b: 'c,

Join to this path another path. Follows standard path rules where if the joined-with path is absolute, the first path is discarded.

pub fn strip_prefix<'b>(&self, prefix: impl Into<Path<'b>>) -> Option<Path<'_>>

Strip a prefix from the path. The prefix and path are allowed to be non-normal and will have “.” components dropped from consideration.

pub fn starts_with<'b>(&self, base: impl Into<Path<'b>>) -> bool

True if the path starts with the provided base path.

pub fn ends_with<'b>(&self, child: impl Into<Path<'b>>) -> bool

True if the path ends with the provided child path.

pub fn parent(&self) -> Option<Path<'_>>

Return the path without its final component, if any.

pub fn ancestors(&self) -> impl Iterator<Item = Path<'static>> + '_

Iterate over the path and its parents.

pub fn file_name(&self) -> Option<&str>

Return the final path component, if it is a normal file name.

pub fn file_stem(&self) -> Option<&str>

Return the file name without its final extension.

pub fn file_prefix(&self) -> Option<&str>

Return the file name without its first extension.

pub fn extension(&self) -> Option<&str>

Return the final file extension without the leading dot.

pub fn with_file_name(&self, file_name: impl AsRef<str>) -> Path<'static>

Create a path like this one, but with its file name replaced.

pub fn with_extension(&self, extension: impl AsRef<str>) -> Path<'static>

Create a path like this one, but with its extension replaced.

pub fn with_added_extension(&self, extension: impl AsRef<str>) -> Path<'static>

Create a path like this one, but with an extension added.

pub fn split(&self) -> (Path<'_>, Path<'_>)

Split the path into basename and dirname components.

pub fn components(&self) -> impl Iterator<Item = Component<'_>>

Return an iterator over the path components. A path with a basename of “.” will always end with Component::CurDir.

pub fn iter(&self) -> impl Iterator<Item = &str>

Iterate over the path components as strings.

pub fn display(&self) -> impl Display + '_

Return a display adapter for the path.

pub fn cwd() -> Option<Path<'a>>

Return the current working directory, if it can be fetched and converted to unicode without error.

pub fn canonicalize(&self) -> Result<Path<'static>, Error>

Return the canonicalized path with all intermediate components normalized and symbolic links resolved.